---
title: plugins
description: adding extra features with plugins.
---

`rovr` supports several plugins to enhance its functionality. you can enable and configure them in your `config.toml` file.

### zoxide

<img
  src="https://github.com/NSPC911/rovr/blob/master/img/0.0.0.4/rovr_zoxide.png"
  alt="rovr's zoxide integration"
/>

[zoxide](https://github.com/ajeetdsouza/zoxide) allows you to zip around your filesystem, and can be integrated into rovr

- **enable:** `plugins.zoxide.enabled = true`
- **keybinding:** the default keybinding to open the zoxide dialog is `z`.

### bat

<img
  src="https://github.com/NSPC911/rovr/blob/master/img/0.0.0.4/rovr_with_bat.png"
  alt="rovr's bat integration"
/>

to allow for more file previews, [bat](https://github.com/sharkdp/bat) can be used for its syntax highlighting capabilities.

- **enable:** `plugins.bat.enabled = true`
- **executable:** you can specify the path to the `bat` executable if it's not in your system's `PATH`.
- **line numbers:** toggle line numbers with `plugins.bat.show_line_numbers`.

### editor

this plugin allows you to open files and folders in your preferred editor.

- **enable:** `plugins.editor.enabled = true`
- **executables:** set the command to open files (`file_executable`) and folders (`folder_executable`).
- **keybinding:** the default keybinding is `e`.

### zen mode

zen mode provides a distraction-free view by hiding all ui elements except for the file list.

- **enable:** `plugins.zen_mode.enabled = true`
- **keybinding:** the default keybinding to toggle zen mode is `shift+z`.
